<?php
/* vim: set ts=4 sw=4 sts=4 et: */
/*****************************************************************************\
+-----------------------------------------------------------------------------+
| X-Cart                                                                      |
| Copyright (c) 2001-2010 Ruslan R. Fazlyev <rrf@x-cart.com>                  |
| All rights reserved.                                                        |
+-----------------------------------------------------------------------------+
| PLEASE READ  THE FULL TEXT OF SOFTWARE LICENSE AGREEMENT IN THE "COPYRIGHT" |
| FILE PROVIDED WITH THIS DISTRIBUTION. THE AGREEMENT TEXT IS ALSO AVAILABLE  |
| AT THE FOLLOWING URL: http://www.x-cart.com/license.php                     |
|                                                                             |
| THIS  AGREEMENT  EXPRESSES  THE  TERMS  AND CONDITIONS ON WHICH YOU MAY USE |
| THIS SOFTWARE   PROGRAM   AND  ASSOCIATED  DOCUMENTATION   THAT  RUSLAN  R. |
| FAZLYEV (hereinafter  referred to as "THE AUTHOR") IS FURNISHING  OR MAKING |
| AVAILABLE TO YOU WITH  THIS  AGREEMENT  (COLLECTIVELY,  THE  "SOFTWARE").   |
| PLEASE   REVIEW   THE  TERMS  AND   CONDITIONS  OF  THIS  LICENSE AGREEMENT |
| CAREFULLY   BEFORE   INSTALLING   OR  USING  THE  SOFTWARE.  BY INSTALLING, |
| COPYING   OR   OTHERWISE   USING   THE   SOFTWARE,  YOU  AND  YOUR  COMPANY |
| (COLLECTIVELY,  "YOU")  ARE  ACCEPTING  AND AGREEING  TO  THE TERMS OF THIS |
| LICENSE   AGREEMENT.   IF  YOU    ARE  NOT  WILLING   TO  BE  BOUND BY THIS |
| AGREEMENT, DO  NOT INSTALL OR USE THE SOFTWARE.  VARIOUS   COPYRIGHTS   AND |
| OTHER   INTELLECTUAL   PROPERTY   RIGHTS    PROTECT   THE   SOFTWARE.  THIS |
| AGREEMENT IS A LICENSE AGREEMENT THAT GIVES  YOU  LIMITED  RIGHTS   TO  USE |
| THE  SOFTWARE   AND  NOT  AN  AGREEMENT  FOR SALE OR FOR  TRANSFER OF TITLE.|
| THE AUTHOR RETAINS ALL RIGHTS NOT EXPRESSLY GRANTED BY THIS AGREEMENT.      |
|                                                                             |
| The Initial Developer of the Original Code is Ruslan R. Fazlyev             |
| Portions created by Ruslan R. Fazlyev are Copyright (C) 2001-2010           |
| Ruslan R. Fazlyev. All Rights Reserved.                                     |
+-----------------------------------------------------------------------------+
\*****************************************************************************/

/**
 * Repository of data cache functions
 *
 * @category   X-Cart
 * @package    X-Cart
 * @subpackage Lib
 * @author     Ruslan R. Fazlyev <rrf@x-cart.com>
 * @copyright  Copyright (c) 2001-2010 Ruslan R. Fazlyev <rrf@x-cart.com>
 * @license    http://www.x-cart.com/license.php X-Cart license agreement
 * @version    $Id: data_cache.php,v 1.42 2010/06/08 07:32:33 joy Exp $
 * @link       http://www.x-cart.com/
 * @see        ____file_see____
 */

if ( !defined('XCART_START') ) { header("Location: ../"); die("Access denied"); }

$data_caches = array(
    'modules'             => array(
        'func' => 'func_dc_modules'
    ),
    'setup_images'         => array(
        'func' => 'func_dc_setup_images'
    ),
    'charsets'             => array(
        'func' => 'func_dc_charsets'
    ),
    'languages'         => array(
        'func' => 'func_dc_languages',
        'func_after_cache' => 'func_dc_after_languages'
    ),
    'payments_https'     => array(
        'func' => 'func_dc_payments_https'
    ),
    'sql'                 => array(
        'func' => 'func_dc_sql',
        'ttl' => SQL_CACHE_TTL,
        'exclude_keys' => array('query')
    ),
);

if (
    empty($config['data_cache_expiration'])
    || (XC_TIME-$config['data_cache_expiration']) > 3600
) {

    func_data_cache_clear();

    $config['data_cache_expiration'] = XC_TIME;

    func_array2insert(
        'config',
        array(
            'value'    => $config['data_cache_expiration'],
            'name'     => 'data_cache_expiration',
            'defvalue' => '',
            'variants' => ''
        ),
        true
    );
}

function func_dc_modules()
{
    global $sql_tbl;

    $all_active_modules = func_query_column("SELECT module_name FROM " . $sql_tbl['modules'] . " USE INDEX (active) WHERE active='Y'");

    $active_modules = array();

    if ($all_active_modules) {
        foreach($all_active_modules as $active_module) {
            $active_modules[$active_module] = true;
        }
    }

    return $active_modules;
}

function func_dc_setup_images()
{
    global $sql_tbl, $xcart_dir;

    $setup_images = func_query_hash("SELECT * FROM " . $sql_tbl['setup_images'], "itype", false);

    if(!empty($setup_images)) {

        $default_images = array();

        foreach($setup_images as $k => $v) {

            if (!empty($v['default_image'])) {

                $tmp = isset($default_images[md5($v['default_image'])])
                    ? $default_images[md5($v['default_image'])]
                    : func_get_image_size($xcart_dir.XC_DS.$v['default_image']);

            }

            if (is_array($tmp)) {
                $setup_images[$k]['image_x'] = $tmp[1];
                $setup_images[$k]['image_y'] = $tmp[2];
            }

        }

    }

    return $setup_images;
}

function func_dc_charsets()
{
    global $sql_tbl;

    return func_query_hash(
        "SELECT " . $sql_tbl['languages'] . ".code, " . $sql_tbl['language_codes'] . ".charset FROM " . $sql_tbl['languages'] . ", " . $sql_tbl['language_codes'] . " WHERE " . $sql_tbl['languages'] . ".code = " . $sql_tbl['language_codes'] . ".code AND " . $sql_tbl['language_codes'] . ".disabled != 'Y' GROUP BY " . $sql_tbl['languages'] . ".code",
        'code',
        false,
        true
    );
}

function func_dc_languages($code)
{
    global $sql_tbl;

    $languages = func_query_hash("SELECT $sql_tbl[language_codes].*, IFNULL(lng_l.value, $sql_tbl[language_codes].language) as language, $sql_tbl[images_G].image_path, $sql_tbl[images_G].image_x, $sql_tbl[images_G].image_y FROM $sql_tbl[languages], $sql_tbl[language_codes] LEFT JOIN $sql_tbl[languages] as lng_l ON lng_l.code = '$code' AND lng_l.name = CONCAT('language_', $sql_tbl[language_codes].code) LEFT JOIN $sql_tbl[images_G] ON $sql_tbl[images_G].id = $sql_tbl[language_codes].lngid WHERE $sql_tbl[languages].code = $sql_tbl[language_codes].code GROUP BY $sql_tbl[languages].code ORDER BY language", 'code', false, false);

    if (!empty($languages)) {

        foreach ($languages as $k => $v) {

            $languages[$k]['code'] = $k;

            if (is_null($v['image_path']))
                unset($languages[$k]['image_path']);

        }

    }

    return $languages;
}

function func_dc_after_languages($languages)
{
    if (!empty($languages)) {

        foreach ($languages as $k => $v) {

            if (!is_null($v['image_path']))
                $languages[$k]['tmbn_url'] = func_get_image_url($v['lngid'], 'G', $v['image_path']);

        }

    }

    return $languages;
}

function func_dc_payments_https()
{
    global $sql_tbl;

    return func_query("SELECT $sql_tbl[payment_methods].paymentid, $sql_tbl[ccprocessors].processor FROM $sql_tbl[payment_methods] USE INDEX (protocol) LEFT JOIN $sql_tbl[ccprocessors] ON $sql_tbl[payment_methods].paymentid = $sql_tbl[ccprocessors].paymentid WHERE $sql_tbl[payment_methods].protocol = 'https'");
}

function func_dc_sql($md5, $query, $type)
{
    switch ($type) {
        case 'first':
            return func_query_first($query);

        case 'first_cell':
            return func_query_first_cell($query);

        default:
            return func_query($query);
    }

    return null;
}

?>
