<?php
/* vim: set ts=4 sw=4 sts=4 et: */
/*****************************************************************************\
+-----------------------------------------------------------------------------+
| X-Cart                                                                      |
| Copyright (c) 2001-2010 Ruslan R. Fazlyev <rrf@x-cart.com>                  |
| All rights reserved.                                                        |
+-----------------------------------------------------------------------------+
| PLEASE READ  THE FULL TEXT OF SOFTWARE LICENSE AGREEMENT IN THE "COPYRIGHT" |
| FILE PROVIDED WITH THIS DISTRIBUTION. THE AGREEMENT TEXT IS ALSO AVAILABLE  |
| AT THE FOLLOWING URL: http://www.x-cart.com/license.php                     |
|                                                                             |
| THIS  AGREEMENT  EXPRESSES  THE  TERMS  AND CONDITIONS ON WHICH YOU MAY USE |
| THIS SOFTWARE   PROGRAM   AND  ASSOCIATED  DOCUMENTATION   THAT  RUSLAN  R. |
| FAZLYEV (hereinafter  referred to as "THE AUTHOR") IS FURNISHING  OR MAKING |
| AVAILABLE TO YOU WITH  THIS  AGREEMENT  (COLLECTIVELY,  THE  "SOFTWARE").   |
| PLEASE   REVIEW   THE  TERMS  AND   CONDITIONS  OF  THIS  LICENSE AGREEMENT |
| CAREFULLY   BEFORE   INSTALLING   OR  USING  THE  SOFTWARE.  BY INSTALLING, |
| COPYING   OR   OTHERWISE   USING   THE   SOFTWARE,  YOU  AND  YOUR  COMPANY |
| (COLLECTIVELY,  "YOU")  ARE  ACCEPTING  AND AGREEING  TO  THE TERMS OF THIS |
| LICENSE   AGREEMENT.   IF  YOU    ARE  NOT  WILLING   TO  BE  BOUND BY THIS |
| AGREEMENT, DO  NOT INSTALL OR USE THE SOFTWARE.  VARIOUS   COPYRIGHTS   AND |
| OTHER   INTELLECTUAL   PROPERTY   RIGHTS    PROTECT   THE   SOFTWARE.  THIS |
| AGREEMENT IS A LICENSE AGREEMENT THAT GIVES  YOU  LIMITED  RIGHTS   TO  USE |
| THE  SOFTWARE   AND  NOT  AN  AGREEMENT  FOR SALE OR FOR  TRANSFER OF TITLE.|
| THE AUTHOR RETAINS ALL RIGHTS NOT EXPRESSLY GRANTED BY THIS AGREEMENT.      |
|                                                                             |
| The Initial Developer of the Original Code is Ruslan R. Fazlyev             |
| Portions created by Ruslan R. Fazlyev are Copyright (C) 2001-2010           |
| Ruslan R. Fazlyev. All Rights Reserved.                                     |
+-----------------------------------------------------------------------------+
\*****************************************************************************/

/**
 * Logging subsystem
 *
 * @category   X-Cart
 * @package    X-Cart
 * @subpackage Lib
 * @author     Ruslan R. Fazlyev <rrf@x-cart.com>
 * @copyright  Copyright (c) 2001-2010 Ruslan R. Fazlyev <rrf@x-cart.com>
 * @license    http://www.x-cart.com/license.php X-Cart license agreement
 * @version    $Id: logging.php,v 1.46 2010/07/28 12:30:02 aim Exp $
 * @link       http://www.x-cart.com/
 * @see        ____file_see____
 */

if ( !defined('XCART_START') ) { header("Location: ../"); die("Access denied"); }

x_load('logging');

set_error_handler('func_error_handler');

/**
 * Set internal php values
 */
if (
    $debug_mode == 2
    || $debug_mode == 0
) {
    ini_set('display_errors', 0);
    ini_set('display_startup_errors', 0);
}

if (
    $debug_mode == 2
    || $debug_mode == 3
) {
    ini_set('log_errors', 1);
    ini_set('error_log', x_log_check_file($var_dirs['log'] . "/x-errors_php-" . func_date('ymd') . ".php"));
    ini_set('ignore_repeated_errors', 1);
}

// Remove empty log for previous day. Purging/checking all empty logs from
// previuos days can reduce performance
$_prev_logfile = $var_dirs['log'] . "/x-errors_php-" . func_date('ymd', XC_TIME - SECONDS_PER_DAY) . ".php";

if (
    file_exists($_prev_logfile)
    && @filesize($_prev_logfile) <= X_LOG_SIGNATURE_LENGTH
) {
    @unlink($_prev_logfile);
}

// Logging PHP IDS statistics
if (
    defined('X_PHPIDS_MSG')
    && constant('X_PHPIDS_MSG')
) {
    x_log_add('SECURITY', "Input data, recognized by PHPIDS as a possible hacking attempt:\n" . X_PHPIDS_MSG);

    if (
        defined('X_USE_ACCESS_DENIED')
        && constant('X_USE_ACCESS_DENIED')
    ) {
        func_header_location('home.php');
    }
}

if (defined('QUICK_START'))
    return true;

/**
 * Log changes of PHP.ini settings
 */
$old_settings = false;

if (file_exists($var_dirs['log'] . '/data.phpini.php')) {

    $fp = @fopen($var_dirs['log'] . '/data.phpini.php');

    if ($fp) {

        @fseek($fp, X_LOG_SIGNATURE_LENGTH);

        $old_settings = @unserialize(@fread($fp, @filesize($var_dirs['log'] . '/data.phpini.php') - X_LOG_SIGNATURE_LENGTH));

        fclose($fp);

    }

    unset($fp);
}

$current_settings = ini_settings_storage(true);

// these optionas are set in config.php
func_unset(
    $current_settings,
    'error_log',
    'ignore_repeated_errors',
    'log_errors',
    'log_errors_max_len',
    'magic_quotes_runtime',
    'session.bug_compat_warn',
    'max_execution_time',
    'mbstring.internal_encoding'
);

$_tmp_changed = false;

if (
    is_array($old_settings)
    && !empty($old_settings)
    && is_array($current_settings)
) {

    $changed_settings = func_array_compare($old_settings, $current_settings);

    $_msg = array();

    if (!empty($changed_settings['removed'])) {

        $_lines = array();

        foreach ($changed_settings['removed'] as $_k => $_v) {

            $_lines[] = "\t$_k = ``$_v''";

        }

        $_msg[] = "Removed options:\n" . implode("\n", $_lines);

        unset($_lines);

    }

    if (!empty($changed_settings['added'])) {

        $_lines = array();

        foreach ($changed_settings['added'] as $_k => $_v) {

            $_lines[] = "\t$_k = ``$_v''";

        }

        $_msg[] = "Added options:\n" . implode("\n", $_lines);

        unset($_lines);

    }

    if (!empty($changed_settings['changed'])) {

        $_lines = array();

        foreach ($changed_settings['changed'] as $_k => $_v) {

            $_lines[] = "\t$_k = '$_v' (was: '" . $old_settings[$_k]."')";

        }

        $_msg[] = "Changed options:\n" . implode("\n", $_lines);

        unset($_lines);

    }

    if (!empty($_msg)) {

        x_log_add('ENV', implode("\n", $_msg));

        $_tmp_changed = true;

    }

    unset($changed_settings);
    unset($_msg);
}

if (
    empty($old_settings)
    || $_tmp_changed
) {
    $_tmp_fp = @fopen($var_dirs['log'] . '/data.phpini.php', 'wb');

    if ($_tmp_fp) {

        @fwrite($_tmp_fp, X_LOG_SIGNATURE . serialize($current_settings));

        @fclose($_tmp_fp);

        func_chmod_file($var_dirs['log'] . '/data.phpini.php');

    }

    unset($_tmp_fp);
}

unset($_tmp_changed, $current_settings, $old_settings);

?>
